package io.swagger.client.api;

import io.swagger.client.ApiClient;

import io.swagger.client.model.Animal;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.client.RestClientException;
import org.springframework.web.client.HttpClientErrorException;
import org.springframework.web.util.UriComponentsBuilder;
import org.springframework.core.ParameterizedTypeReference;
import org.springframework.core.io.FileSystemResource;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;

@Component("io.swagger.client.api.AnimalApi")
public class AnimalApi {
    private ApiClient apiClient;

    public AnimalApi() {
        this(new ApiClient());
    }

    @Autowired
    public AnimalApi(ApiClient apiClient) {
        this.apiClient = apiClient;
    }

    public ApiClient getApiClient() {
        return apiClient;
    }

    public void setApiClient(ApiClient apiClient) {
        this.apiClient = apiClient;
    }

    /**
     * Add a new animal to the store
     * 
     * <p><b>405</b> - Invalid input
     * @param body Animal object that needs to be added to the store (required)
     * @throws RestClientException if an error occurs while attempting to invoke the API
     */
    public void addAnimal(Animal body) throws RestClientException {
        addAnimalWithHttpInfo(body);
    }

    /**
     * Add a new animal to the store
     * 
     * <p><b>405</b> - Invalid input
     * @param body Animal object that needs to be added to the store (required)
     * @return ResponseEntity&lt;Void&gt;
     * @throws RestClientException if an error occurs while attempting to invoke the API
     */
    public ResponseEntity<Void> addAnimalWithHttpInfo(Animal body) throws RestClientException {
        Object postBody = body;
        // verify the required parameter 'body' is set
        if (body == null) {
            throw new HttpClientErrorException(HttpStatus.BAD_REQUEST, "Missing the required parameter 'body' when calling addAnimal");
        }
        String path = UriComponentsBuilder.fromPath("/animal").build().toUriString();
        
        final MultiValueMap<String, String> queryParams = new LinkedMultiValueMap<String, String>();
        final HttpHeaders headerParams = new HttpHeaders();
        final MultiValueMap<String, Object> formParams = new LinkedMultiValueMap<String, Object>();

        final String[] accepts = {  };
        final List<MediaType> accept = apiClient.selectHeaderAccept(accepts);
        final String[] contentTypes = { 
            "application/json", "application/xml"
         };
        final MediaType contentType = apiClient.selectHeaderContentType(contentTypes);

        String[] authNames = new String[] {  };

        ParameterizedTypeReference<Void> returnType = new ParameterizedTypeReference<Void>() {};
        return apiClient.invokeAPI(path, HttpMethod.POST, queryParams, postBody, headerParams, formParams, accept, contentType, authNames, returnType);
    }
    /**
     * Deletes a animal
     * 
     * <p><b>400</b> - Invalid animal value
     * @param animalId Animal id to delete (required)
     * @param apiKey  (optional)
     * @throws RestClientException if an error occurs while attempting to invoke the API
     */
    public void deleteAnimal(Long animalId, String apiKey) throws RestClientException {
        deleteAnimalWithHttpInfo(animalId, apiKey);
    }

    /**
     * Deletes a animal
     * 
     * <p><b>400</b> - Invalid animal value
     * @param animalId Animal id to delete (required)
     * @param apiKey  (optional)
     * @return ResponseEntity&lt;Void&gt;
     * @throws RestClientException if an error occurs while attempting to invoke the API
     */
    public ResponseEntity<Void> deleteAnimalWithHttpInfo(Long animalId, String apiKey) throws RestClientException {
        Object postBody = null;
        // verify the required parameter 'animalId' is set
        if (animalId == null) {
            throw new HttpClientErrorException(HttpStatus.BAD_REQUEST, "Missing the required parameter 'animalId' when calling deleteAnimal");
        }
        // create path and map variables
        final Map<String, Object> uriVariables = new HashMap<String, Object>();
        uriVariables.put("animalId", animalId);
        String path = UriComponentsBuilder.fromPath("/animal/{animalId}").buildAndExpand(uriVariables).toUriString();
        
        final MultiValueMap<String, String> queryParams = new LinkedMultiValueMap<String, String>();
        final HttpHeaders headerParams = new HttpHeaders();
        final MultiValueMap<String, Object> formParams = new LinkedMultiValueMap<String, Object>();
        if (apiKey != null)
            headerParams.add("api_key", apiClient.parameterToString(apiKey));

        final String[] accepts = {  };
        final List<MediaType> accept = apiClient.selectHeaderAccept(accepts);
        final String[] contentTypes = {  };
        final MediaType contentType = apiClient.selectHeaderContentType(contentTypes);

        String[] authNames = new String[] {  };

        ParameterizedTypeReference<Void> returnType = new ParameterizedTypeReference<Void>() {};
        return apiClient.invokeAPI(path, HttpMethod.DELETE, queryParams, postBody, headerParams, formParams, accept, contentType, authNames, returnType);
    }
    /**
     * Find animal by ID
     * Returns a single animal
     * <p><b>200</b> - successful operation
     * <p><b>400</b> - Invalid ID supplied
     * <p><b>404</b> - Pet not found
     * @param animalId ID of pet to return (required)
     * @return Animal
     * @throws RestClientException if an error occurs while attempting to invoke the API
     */
    public Animal getAnimalById(Long animalId) throws RestClientException {
        return getAnimalByIdWithHttpInfo(animalId).getBody();
    }

    /**
     * Find animal by ID
     * Returns a single animal
     * <p><b>200</b> - successful operation
     * <p><b>400</b> - Invalid ID supplied
     * <p><b>404</b> - Pet not found
     * @param animalId ID of pet to return (required)
     * @return ResponseEntity&lt;Animal&gt;
     * @throws RestClientException if an error occurs while attempting to invoke the API
     */
    public ResponseEntity<Animal> getAnimalByIdWithHttpInfo(Long animalId) throws RestClientException {
        Object postBody = null;
        // verify the required parameter 'animalId' is set
        if (animalId == null) {
            throw new HttpClientErrorException(HttpStatus.BAD_REQUEST, "Missing the required parameter 'animalId' when calling getAnimalById");
        }
        // create path and map variables
        final Map<String, Object> uriVariables = new HashMap<String, Object>();
        uriVariables.put("animalId", animalId);
        String path = UriComponentsBuilder.fromPath("/animal/{animalId}").buildAndExpand(uriVariables).toUriString();
        
        final MultiValueMap<String, String> queryParams = new LinkedMultiValueMap<String, String>();
        final HttpHeaders headerParams = new HttpHeaders();
        final MultiValueMap<String, Object> formParams = new LinkedMultiValueMap<String, Object>();

        final String[] accepts = { 
            "application/xml", "application/json"
         };
        final List<MediaType> accept = apiClient.selectHeaderAccept(accepts);
        final String[] contentTypes = {  };
        final MediaType contentType = apiClient.selectHeaderContentType(contentTypes);

        String[] authNames = new String[] {  };

        ParameterizedTypeReference<Animal> returnType = new ParameterizedTypeReference<Animal>() {};
        return apiClient.invokeAPI(path, HttpMethod.GET, queryParams, postBody, headerParams, formParams, accept, contentType, authNames, returnType);
    }
    /**
     * Update an existing animal
     * 
     * <p><b>400</b> - Invalid ID supplied
     * <p><b>404</b> - Animal not found
     * <p><b>405</b> - Validation exception
     * @param body Animal object that needs to be added. (required)
     * @throws RestClientException if an error occurs while attempting to invoke the API
     */
    public void updateAnimal(Animal body) throws RestClientException {
        updateAnimalWithHttpInfo(body);
    }

    /**
     * Update an existing animal
     * 
     * <p><b>400</b> - Invalid ID supplied
     * <p><b>404</b> - Animal not found
     * <p><b>405</b> - Validation exception
     * @param body Animal object that needs to be added. (required)
     * @return ResponseEntity&lt;Void&gt;
     * @throws RestClientException if an error occurs while attempting to invoke the API
     */
    public ResponseEntity<Void> updateAnimalWithHttpInfo(Animal body) throws RestClientException {
        Object postBody = body;
        // verify the required parameter 'body' is set
        if (body == null) {
            throw new HttpClientErrorException(HttpStatus.BAD_REQUEST, "Missing the required parameter 'body' when calling updateAnimal");
        }
        String path = UriComponentsBuilder.fromPath("/animal").build().toUriString();
        
        final MultiValueMap<String, String> queryParams = new LinkedMultiValueMap<String, String>();
        final HttpHeaders headerParams = new HttpHeaders();
        final MultiValueMap<String, Object> formParams = new LinkedMultiValueMap<String, Object>();

        final String[] accepts = {  };
        final List<MediaType> accept = apiClient.selectHeaderAccept(accepts);
        final String[] contentTypes = { 
            "application/json", "application/xml"
         };
        final MediaType contentType = apiClient.selectHeaderContentType(contentTypes);

        String[] authNames = new String[] {  };

        ParameterizedTypeReference<Void> returnType = new ParameterizedTypeReference<Void>() {};
        return apiClient.invokeAPI(path, HttpMethod.PUT, queryParams, postBody, headerParams, formParams, accept, contentType, authNames, returnType);
    }
    /**
     * Updates a animal
     * 
     * <p><b>405</b> - Invalid input
     * @param animalId ID of animal that needs to be updated (required)
     * @param name  (optional)
     * @param status  (optional)
     * @throws RestClientException if an error occurs while attempting to invoke the API
     */
    public void updateAnimalWithForm(Long animalId, String name, String status) throws RestClientException {
        updateAnimalWithFormWithHttpInfo(animalId, name, status);
    }

    /**
     * Updates a animal
     * 
     * <p><b>405</b> - Invalid input
     * @param animalId ID of animal that needs to be updated (required)
     * @param name  (optional)
     * @param status  (optional)
     * @return ResponseEntity&lt;Void&gt;
     * @throws RestClientException if an error occurs while attempting to invoke the API
     */
    public ResponseEntity<Void> updateAnimalWithFormWithHttpInfo(Long animalId, String name, String status) throws RestClientException {
        Object postBody = null;
        // verify the required parameter 'animalId' is set
        if (animalId == null) {
            throw new HttpClientErrorException(HttpStatus.BAD_REQUEST, "Missing the required parameter 'animalId' when calling updateAnimalWithForm");
        }
        // create path and map variables
        final Map<String, Object> uriVariables = new HashMap<String, Object>();
        uriVariables.put("animalId", animalId);
        String path = UriComponentsBuilder.fromPath("/animal/{animalId}").buildAndExpand(uriVariables).toUriString();
        
        final MultiValueMap<String, String> queryParams = new LinkedMultiValueMap<String, String>();
        final HttpHeaders headerParams = new HttpHeaders();
        final MultiValueMap<String, Object> formParams = new LinkedMultiValueMap<String, Object>();
        if (name != null)
            formParams.add("name", name);
        if (status != null)
            formParams.add("status", status);

        final String[] accepts = {  };
        final List<MediaType> accept = apiClient.selectHeaderAccept(accepts);
        final String[] contentTypes = { 
            "application/x-www-form-urlencoded"
         };
        final MediaType contentType = apiClient.selectHeaderContentType(contentTypes);

        String[] authNames = new String[] {  };

        ParameterizedTypeReference<Void> returnType = new ParameterizedTypeReference<Void>() {};
        return apiClient.invokeAPI(path, HttpMethod.POST, queryParams, postBody, headerParams, formParams, accept, contentType, authNames, returnType);
    }
}
